@@ -19,6 +19,7 @@
 
 #include "background_process.h"
 #include "set_tone.h"
+#include "rtty.h"
 
 extern int stop_backgrnd_process;
 extern int this_second;
@@ -41,6 +42,9 @@ extern char zone_export[];
 extern long lantime;
 extern long timecorr;
 extern int timeoffset;
+extern char call[];
+extern int trxmode;
+extern int keyerport;
 
 
 int background_process(void){
@@ -74,6 +78,10 @@ i = 1;
 			receive_packet();
 			
 		}
+
+		if (trxmode == DIGIMODE && (keyerport == MFJ1278_KEYER || keyerport == GMFSK))
+			rx_rtty();
+
 		
 		if (this_second != last_second) {    /* once per second */
 			last_second = this_second;
@@ -111,9 +119,10 @@ i = 1;
 			}
 
 
-		  if (landebug ==1){
+		  if (landebug ==1)
+		  {
 			if  ( (fp = fopen("debuglog","a"))  == NULL){
-				fprintf(stdout,  "store_qso.c: Error opening file.\n");
+				fprintf(stdout,  "store_qso.c: Error opening debug file.\n");
 
 			}
 			get_time();
@@ -127,7 +136,18 @@ i = 1;
 
 			fclose(fp);
 		  }
-		if ((strlen(lan_message) > 0) && (lan_message[0] != thisnode) && (stop_backgrnd_process != 1)) {
+		if ((strlen(lan_message) > 0)
+			&& (lan_message[0] == thisnode))
+		{
+			mvprintw(24,0, "Warning: NODE ID CONFLICT ?! You should use another ID! ");
+			refresh();
+			sleep(5);
+		}
+
+		if ((strlen(lan_message) > 0)
+			&& (lan_message[0] != thisnode)
+			&& (stop_backgrnd_process != 1))
+		{
 
 			switch (lan_message[1]) {
 
@@ -146,6 +166,13 @@ i = 1;
 			         	break;
 				case CLUSTERMSG :
 					strncpy(prmessage, lan_message + 2, 80);
+					if (strstr(prmessage, call) != NULL)		// alert for cluster messages
+					{
+						mvprintw(24,0, "                                                                           ");
+						mvprintw(24,0, "%s", prmessage);
+						refresh();
+					}
+
 					addtext(prmessage);
 				    break;
 				case TLFSPOT:
@@ -161,8 +188,8 @@ i = 1;
 					talkarray[4][1]=':';
 					talkarray[4][2]='\0';
 					strncat (talkarray[4], lan_message+2, 60);
-					mvprintw(24,2, "                                                                           ");
-					mvprintw(24,2, " MSG from %s", talkarray[4]);
+					mvprintw(24,0, "                                                                           ");
+					mvprintw(24,0, " MSG from %s", talkarray[4]);
 					refresh();
 					break;
 				case FREQMSG:
