@@ -22,26 +22,15 @@
  	*
  	*--------------------------------------------------------------*/
 
+#include "globalvars.h"
 #include "edit_last.h"
 #include "clear_display.h"
 
+char logline_edit[5][82];
+
 int edit_last(void)
 {
  	
- 	extern char logfile[];
-	extern int stop_backgrnd_process;
-
-	extern char logline0[];
-	extern char logline1[];
-	extern char logline2[];
-	extern char logline3[];
-	extern char logline4[];
-
-	extern char qsos[MAX_QSOS][81];
-	extern int nr_qsos;
-
-
-	char logline_edit[5][82];
   	int j=0, b, k, ii=0;
 	int lfile;
 	struct stat statbuf;
@@ -49,21 +38,14 @@ int edit_last(void)
 
 	stop_backgrnd_process = 1;         //(no qso add during edit process)
 
-	strcpy(logline_edit[0], logline0);
-	strcpy(logline_edit[1], logline1);
-	strcpy(logline_edit[2], logline2);
-	strcpy(logline_edit[3], logline3);
-	strcpy(logline_edit[4], logline4);
-
-
 	attron(A_STANDOUT);
 
 	attron(COLOR_PAIR(COLOR_GREEN));
-	 mvprintw(7 + editline,0, logline_edit[editline]);
+	mvprintw(7 + editline,0, logline_edit[editline]);
 
 
 
-	 b =  29;
+	b =  29;
 	mvprintw(7 + editline, b, "");
 
 	while ((j != 27) && (j != '\n')){
@@ -236,54 +218,46 @@ int edit_last(void)
  	mvprintw(7 + editline,0, logline_edit[editline]);
 	refresh();
 
-		if ((lfile = open(logfile, O_RDWR)) < 0){
+	if ((lfile = open(logfile, O_RDWR)) < 0){
 
-			mvprintw(24,0, "I can not find the logfile...");
-			refresh();
-			sleep(2);
-		}  else {
+		mvprintw(24,0, "I can not find the logfile...");
+		refresh();
+		sleep(2);
+	}  else {
 
 
-			for (ii = 4; ii >=0; ii--) {
+		for (ii = 4; ii >=0; ii--) {
 
-				fstat(lfile, &statbuf);
+			fstat(lfile, &statbuf);
 
-				if(statbuf.st_size >  80) {
-					ftruncate(lfile, statbuf.st_size -  81);
-					nr_qsos--;
-					qsos[nr_qsos][0]='\0';
-					fsync(lfile);
-
-				} else break;
-
-			}
+			if(statbuf.st_size >  80) {
+				ftruncate(lfile, statbuf.st_size -  81);
+				nr_qsos--;
+				qsos[nr_qsos][0]='\0';
+				fsync(lfile);
 
+			} else break;
 
 		}
 
-		close(lfile);
 
-			ii++;
+	}
 
-			while (ii < 5) {
-				strcpy(logline4, logline_edit[ii]);
-				store_qso();
-				ii++;
-			}
+	close(lfile);
+
+	ii++;
+
+	while (ii < 5) {
+		store_qso(logline_edit[ii]);
+		ii++;
+	}
 
 
+	scroll_log();
 
-	strcpy(logline0,logline_edit[0]);
-	strcpy(logline1,logline_edit[1]);
-	strcpy(logline2,logline_edit[2]);
-	strcpy(logline3,logline_edit[3]);
-	strcpy(logline4,logline_edit[4]);
+	stop_backgrnd_process = 0;
 
-		scroll_log();
-
-		stop_backgrnd_process = 0;
-
- return(0);
+	return(0);
 }
 
 
