@@ -1,6 +1,6 @@
 /*
  * Tlf - contest logging program for amateur radio operators
- * Copyright (C) 2001-2002-2003 Rein Couperus <pa0r@eudx.org>
+ * Copyright (C) 2001-2002-2003-2004-2005 Rein Couperus <pa0r@eudx.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -29,14 +29,17 @@ int play_file(char *audiofile);
 
 int getexchange(void)
 {
+extern int contest;
 extern int use_rxvt;
 extern char comment[];
 extern char cqzone[];
 extern char ituzone[];
 extern char my_rst[];
+extern char speedstr[];
+extern int change_rst;
 extern int cury, curx;
 extern char message[15][80];
-extern char ph_message[14][40];
+extern char ph_message[14][80];
 extern char hiscall[];
 extern char buffer[];
 extern char qsonrstr[];
@@ -58,6 +61,7 @@ extern char qsonrstr[];
 extern char call[];
 extern char section[];
 extern int serial_section_mult;
+extern int serial_grid4_mult;
 extern int sectn_mult;
 extern int dx_arrlsections;
 extern int ctcomp;
@@ -66,13 +70,19 @@ extern int itumult;
 extern int pfxmult;
 extern int exc_cont;
 extern char continent[];
-
+extern int keyerport;
+extern int commentfield;
+extern int dxped;
 
 int  i;
 int x = 0;
 char instring[2];
 char commentbuf[40]  = "";
 int retval;
+char * gridmult = "";
+int keyspeed = 30;
+char speedbuf[3] = "";
+
 
 instring[1] = '\0';
 
@@ -112,25 +122,25 @@ instring[1] = '\0';
 
 	mvprintw(12, 54, "                          ");
 	mvprintw(12, 54, comment);
-
+commentfield = 1;
 	for  (i=strlen(comment) ; i<=25; i++)
 	{
 		x  =  onechar();
 
 			if  ( x == 127 && (strlen(comment) >= 1))
 				{      /* erase  */
-					
-			
+
+
 		 			getyx(stdscr, cury,  curx);
 			 		mvprintw(12, curx - 1, " ");
 			 		mvprintw(12, curx  - 1, "");
 					comment[strlen(comment)-1] = '\0';
 					i -= 2;
 				}
-				
-						 					
+
+
 				switch(x){
-						
+
 						case 27:
 						{
 						 if (comment[0] != '\0')
@@ -160,7 +170,7 @@ instring[1] = '\0';
 
 						break;
 						}
-						case '+' :                                             // for CT compatibility
+						case '+' :                                           // for CT compatibility
 						{
    							if (strlen(hiscall) > 2) {
 								if (trxmode == CWMODE) {
@@ -189,7 +199,7 @@ instring[1] = '\0';
 						}
 
 
-						
+
 						case 130 ... 137:
 						{
 							if (trxmode == CWMODE) {
@@ -212,29 +222,50 @@ instring[1] = '\0';
 							break;
 						}
 
-						
+
 						 case 156:                          /* change MY RST */
 						{
+							if (change_rst == 1) {
+							 	if (my_rst[1] <= 56){
 
-						 	if (my_rst[1] <= 56){
+							 	 	my_rst[1]++;
 
-						 	 	my_rst[1]++;
-						 	 	
-						 	 	mvprintw(12, 49, my_rst);
-						 	 	mvprintw(12, 54, comment);
+							 	 	mvprintw(12, 49, my_rst);
+							 	 	mvprintw(12, 54, comment);
+							 	}
+						 	} else {						/* speed up */
+		 						keyspeed = speedup();
+								strncpy(speedbuf, speedstr +  (2  *  keyspeed), 2);
+								speedbuf[2] =  '\0';
+//								attron(COLOR_PAIR(COLOR_GREEN) | A_STANDOUT);
+
+				 				mvprintw(0, 14, "%s", speedbuf);
+							 	mvprintw(12, 54, comment);
+								refresh();
+						 	
 						 	}
 						 	break;
-						
+
 						}
 						case 157:
 						{
+							if (change_rst == 1) {
 
-						 	if (my_rst[1] >= 49){
-						 	 	my_rst[1]--;
+							 	if (my_rst[1] >= 49){
+							 	 	my_rst[1]--;
 
-						 	 	mvprintw(12, 49, my_rst);
-						 	 	mvprintw(12, 54, comment);
+							 	 	mvprintw(12, 49, my_rst);
+							 	 	mvprintw(12, 54, comment);
 
+							 	}
+						 	} else {
+								keyspeed = speeddown();
+								strncpy(speedbuf, speedstr +  (2  *  keyspeed), 2);
+								speedbuf[2] =  '\0';
+		//						attron(COLOR_PAIR(COLOR_GREEN) | A_STANDOUT);
+				 				mvprintw(0, 14, "%s", speedbuf);
+								mvprintw(12, 54, comment);
+								refresh(); 	
 						 	}
 						 	break;
 
@@ -251,7 +282,10 @@ instring[1] = '\0';
 						case '\n' :
 						{
 							if (ctcomp == 1) x = 92;  // enter logs immediately
-						break;
+							if (trxmode == SSBMODE) x = 92;
+							if (contest != 1) x = 92;
+//							if (dxped == 1) x = 92;
+							break;
 						}
 
 
@@ -269,6 +303,10 @@ instring[1] = '\0';
 				instring[0] = x;
 				addch(x);
 				strcat(comment, instring);
+				if (keyerport == GMFSK){
+					show_rtty();
+					mvprintw(12, 54, comment);
+				}
 				refresh();
 			}
 		}  else i--;
@@ -279,7 +317,6 @@ instring[1] = '\0';
 		if (arrlss == 1)  x = checkexchange(x);
 		if (cqww == 1)  x = checkexchange(x);
 
-
 		if (x == '\n' || x == 9 ||  x == 11|| x == 92){
 
 			if  ( (exchange_serial ==1)){         /* align serial nr. */
@@ -319,7 +356,7 @@ instring[1] = '\0';
 			}
 
 			if (sprint == 1) {
-			
+
 			 	if ((comment[1] == ' ') && (comment[0] != ' ')){
 
 			 	 	strcpy(commentbuf, "00");
@@ -337,9 +374,9 @@ instring[1] = '\0';
 			 	 	strcat (commentbuf, comment + 2);
 			 	 	strcpy (comment, commentbuf);
 			 	}
-			
+
 			}
-			
+
 			if ((pacc_pa_flg == 1) && (countrynr != mycountrynr)) {
 			 	if (strlen(comment)  ==  1){
 			 	 	strcpy(commentbuf,  comment);
@@ -366,15 +403,27 @@ instring[1] = '\0';
 				mvprintw(13,54, "section?");
 				mvprintw(12,54, comment);
 				refresh();
-//				x = 0;
+
+				x = 0; //##debug
+			} else if  (serial_grid4_mult == 1) {
+			//	mvprintw(13,54, "section?");
+				mvprintw(12,54, comment);
+				refresh();
+				gridmult = getgrid(comment);
+				strcpy (section, gridmult);
+				section[4] = '\0';
+
+				break;
+//				x = 0; //##debug
+
 			} else
 				break;
 
 
 		}
-		
-	}
 
+	}
+commentfield = 0;
 
  	return(x);
 }
@@ -383,7 +432,7 @@ instring[1] = '\0';
 
 char cmpattern[]="                               ";            // global
 char ssexchange[30] = "";
- char section[4]="";
+ char section[8]="";
  char callupdate[7];
  int call_update = 0;
  char zone_export[3] = "  ";
@@ -397,7 +446,7 @@ int checkexchange (int x) {
 	extern char mults_possible[MAX_MULTS][12] ;
 	extern int cqww;
 	extern int arrlss;
-	extern char section[4];
+	extern char section[];
 	extern char callupdate[];
 	extern char hiscall[];
 	extern  int call_update;
@@ -804,12 +853,10 @@ if ((serial_section_mult == 1) || (sectn_mult == 1) || dx_arrlsections == 1) {
 							{
 								checksection[strlen(checksection)-1] = '\0';
 							}
-//							checksection[3]='\0';
 
 							for (jj=0 ; jj < MAX_MULTS ; jj++)
 							{
 
-//								if ((strlen(mults_possible[jj] )>=1) &&  (strstr(checksection, mults_possible[jj]) != NULL))
 								if ((strlen(mults_possible[jj] )>=1) &&  (strcmp(checksection, mults_possible[jj]) == 0))
 								{
 									strcpy (section, mults_possible[jj]);
@@ -831,7 +878,6 @@ if ((serial_section_mult == 1) || (sectn_mult == 1) || dx_arrlsections == 1) {
 
 							strncpy (checksection, comment, 3);
 							checksection[3]='\0';
-
 							for (jj=0 ; jj < max_multipliers ; jj++) {
 
 								if ((strlen(mults_possible[jj] )>=1) &&  (strstr(checksection, mults_possible[jj]) != NULL)) {
@@ -960,3 +1006,21 @@ int i, x = 0;
 return(x);
 
 }
+/*  --------------------------------------------------------------------------*/
+
+char * getgrid (char *comment) {
+
+char * gridmult = "";
+int multposition = 0;
+int i = 0;
+
+for (i=0; i < strlen(comment); i++) {
+	if (comment[i] > 64 && comment[i] < 91) {
+		multposition = i;
+		break;
+	}
+}
+gridmult = comment + multposition;
+
+return (gridmult);
+}
