@@ -25,6 +25,7 @@
 
 #include "globalvars.h"
 #include "getmessages.h"
+#include "qsonr_to_str.h"
 
 int getmessages(void)
 {
@@ -111,6 +112,7 @@ if (qsonum == 1){
  	strncpy(qsonrstr, logline[3] +23,  4);
  	qsonrstr[4] = '\0';
 	qsonum = atoi(qsonrstr) + 1;
+	qsonr_to_str();
 }
 	
 if (strlen(logline[0]) >= 75)
