@@ -36,6 +36,7 @@
  	extern char exchange[];
 	extern int multcount;
 	extern int arrlss;
+	extern int serial_section_mult;
  	
  	int getsummary(void)
  	{
@@ -49,7 +50,7 @@
 		fprintf(stdout,  "Error opening header file.\n");
 		return(1);
 	}
- 	
+
 	fputs("START-OF-LOG: 2.0\n", fp);
 
 		attron(A_STANDOUT);
@@ -60,7 +61,7 @@
 		echo();
 		getnstr(buffer, 78);
 		noecho();
-		strncpy(exchange, buffer, 3);
+		strncpy(exchange, buffer, 10);
 		
 		attron(A_STANDOUT);
         mvprintw(15,1, "                                                                                    ");
@@ -68,15 +69,17 @@
         attron(A_STANDOUT);
         mvprintw(15,1,"");
 	
-	fputs("ARRL-SECTION: ", fp);
 		echo();
 		getnstr(buffer, 78);
 		noecho();
 		strcat(buffer, "\n");
-	fputs(buffer, fp);
-	fputs("CALLSIGN: ", fp);
-	fputs(call, fp);
-	fputs("CATEGORY: ",  fp);
+		if (strncmp(buffer, "none", 4) != 0) {
+			fputs("ARRL-SECTION: ", fp);
+			fputs(buffer, fp);
+		}
+		fputs("CALLSIGN: ", fp);
+		fputs(call, fp);
+		fputs("CATEGORY: ",  fp);
 	
         attron(A_STANDOUT);
         mvprintw(15,1, "                                                                                    ");
@@ -143,6 +146,9 @@
 	    sprintf(buffer, "%d\n",total  * totalmults);
 	if (arrlss == 1)
 		sprintf(buffer, "%d\n", multcount * total);
+	if (serial_section_mult == 1)
+		sprintf(buffer, "%d\n", totalmults * total);
+
 	fputs("CLAIMED-SCORE: ", fp);
 	fputs( buffer, fp);
 	fputs("CLUB: ", fp);
@@ -160,7 +166,7 @@
 	fputs("CONTEST: ", fp);
         attron(A_STANDOUT);
         mvprintw(15,1, "                                                                                    ");
-        nicebox(14,0, 1, 78, "Contest: (CQ-WW-CW/SSB, WPX-CW/SSB, ARRL-DX-CW/SSB)");
+        nicebox(14,0, 1, 78, "Contest: (CQ-WW-CW/SSB, CQ-WPX-CW/SSB, ARRL-DX-CW/SSB)");
         attron(A_STANDOUT);
         mvprintw(15,1,"");
      	
@@ -168,14 +174,19 @@
 		getnstr(buffer, 78);
 		noecho();
 		strcat(buffer, "\n");
-	fputs(buffer, fp);
-	fputs("CREATED-BY: tlf-0.8.20\n", fp);
-        attron(A_STANDOUT);
+		fputs(buffer, fp);
+// LU4HKN mod.
+		strcpy(buffer, "CREATED-BY: tlf-");
+		strcat(buffer, VERSION);
+		strcat(buffer, "\n");
+		fputs(buffer, fp);
+ // end
+		attron(A_STANDOUT);
         mvprintw(15,1, "                                                                                    ");
         nicebox(14,0, 1, 78, "Name: ");
         attron(A_STANDOUT);
         mvprintw(15,1,"");
-     	
+
      	echo();
 		getnstr(buffer, 78);
 		noecho();
