@@ -1,6 +1,6 @@
 /*
  * Tlf - contest logging program for amateur radio operators
- * Copyright (C) 2001-2002-2003 Rein Couperus <pa0rct@amsat.org>
+ * Copyright (C) 2001-2002-2003-2004-2005 Rein Couperus <pa0r@amsat.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -34,7 +34,7 @@ extern int cqmode;
 extern int contest;
 extern char buffer[];
 extern char message[15][80];
-extern char ph_message[14][40];
+extern char ph_message[14][80];
 extern char comment[];
 extern int cqww;
 extern char cqzone[];
@@ -54,6 +54,7 @@ extern int itumult;
 extern int qsonum;
 extern int exchange_serial;
 extern char tonestr[];
+extern int dxped;
 
 int callreturn = 0;
 int qrg_out = 0;
@@ -98,7 +99,7 @@ else
   	if (callreturn == '\n' && strlen(hiscall) >= 3 )
    	{
 
-    		if (!strlen(comment) && contest == CONTEST && !ctcomp && defer_store)
+    	if (!strlen(comment) && contest == CONTEST && !ctcomp && !dxped)
 		    defer_store = 0;
 		if  ((cqmode ==  CQ ) && (contest == CONTEST  ) && (defer_store == 0)){         /* contest */
 				if (trxmode == CWMODE || trxmode == DIGIMODE)
