@@ -56,6 +56,7 @@
 						};
   int debugflag = 0;
   int editor = EDITOR_JOE;
+  char rttyoutput[120];
   int use_vk = 0;
   int tune_val = 0;
   int use_bandoutput = 0;
@@ -133,7 +134,9 @@
   int ua9_cty;
 
   char tlfversion[80] = "";
-  char multiplierlist[40]="";
+  char testbuffer[120] = "";
+  char multiplierlist[80]="";
+  char multsfile[80] = "";
   char exchange_list[40] = "";
   int timeoffset=0;
   int multi = 0;                /* 0 = SO , 1 = MOST, 2 = MM */
@@ -224,6 +227,8 @@
 	int k_ptt;
 char controllerport[80] = "/dev/ttyS0";
 int miniterm = 0;
+char modem_mode[8];
+int commentfield = 0;
 
 /*-------------------------------------packet-------------------------------*/
   char spot_ptr[MAX_SPOTS][82];
@@ -612,7 +617,7 @@ if (main_ie_list == NULL)
 			showmsg("Keyer is cwdaemon");
 			if (verbose == 1) sleep(1);
 		 }
-		 if (keyerport == MFJ1278_KEYER) {
+		 if (keyerport == MFJ1278_KEYER || keyerport == GMFSK) {
 			init_controller();
 		 }
 
