@@ -53,7 +53,8 @@ int include_note(void)
 
 		if (lan_active == 1) {
 			sprintf(buffer2, "; Node %c, %d : ", thisnode, atoi(qsonrstr) - 1);
-		}
+		}else
+			sprintf(buffer2, "; ");
 
 		if (strlen(buffer) >= 1){
 			strncat(buffer2,  buffer,  strlen(buffer)); /* strip \n */
