@@ -179,7 +179,7 @@ int parse_logcfg(char *inputbuffer){
 	extern int timeoffset;
 	extern int time_master;
 	extern int ctcomp;
-	extern char multiplierlist[40];
+	extern char multiplierlist[];
 	extern int multlist;
 	extern int universal;
 	extern int serial_section_mult;
@@ -208,6 +208,7 @@ int parse_logcfg(char *inputbuffer){
 	extern int lowband_point_mult;
 	extern int sc_sidetone;
 	extern char sc_volume[];
+	extern char modem_mode[];
 
 /* LZ3NY mods */
 extern int mult_side;
@@ -238,7 +239,7 @@ extern char clusterlogin[];
 extern int cw_bandwidth;
 extern int nobandchange;
 extern int change_rst;
-
+extern char rttyoutput[];
 
 
 	char commands[MAX_COMMANDS][30]= {
@@ -392,8 +393,12 @@ extern int change_rst;
 		"CLUSTER_LOG",
 		"SERIAL+GRID4",
 		"CHANGE_RST",
+		"GMFSK=",
+		"RTTYMODE",					/* 150 */
+		"DIGIMODEM=",
+		"",
+		"",
 		""
-		
 	};
 
 	char teststring[80];
@@ -406,7 +411,7 @@ extern int change_rst;
 	char *tk_ptr;
 
 
-	for (ii = 0; ii <= MAX_COMMANDS; ii++) {
+	for (ii = 0; ii < MAX_COMMANDS; ii++) {
 
 		teststring[0] = '\0';
 		strncat(teststring, commands[ii], 79);
@@ -810,7 +815,7 @@ extern int change_rst;
 			}
 			case 87 : {
 					multiplierlist[0] = '\0';
-					strcat(multiplierlist, inputbuffer + 10);
+					strncat(multiplierlist, inputbuffer + 10, 79);
 					multlist = 1;
 				universal = 1;
 				break;
@@ -1181,6 +1186,24 @@ extern int change_rst;
 					change_rst = 1;
 					break;
 			}
+			case 149 : {
+				keyerport = GMFSK;
+				strncpy(controllerport, inputbuffer + 6, sizeof (controllerport) -1 );
+				controllerport[strlen(controllerport)-1] = '\0';
+				break;
+			}
+ 			case 150: {	// start in digital mode
+ 				trxmode = DIGIMODE;
+ 				modem_mode[0] = '\0';
+ 				strcat(modem_mode, "RTTY");
+ 				break;
+ 			}
+			case 151 : {
+				rttyoutput[0] = '\0';
+				strncat(rttyoutput, inputbuffer + 10, 110);
+				rttyoutput[strlen(rttyoutput)-1] = '\0';
+				break;
+			}
 
 		}
 
