@@ -32,13 +32,14 @@
 #include <unistd.h>
 #include <fcntl.h>
 #include "tlf.h"
+#include "printcall.h"
 
 static int fdcont;		// global for this file: tty file descriptor
 static char ry_term[4][50] = {"", "", "", "" };
 
 /* ------------------------------------- initialize  controller --------------------------------- */
 int init_controller() {
-
+ 
 extern char controllerport[];
 
 struct termios termattribs;
@@ -72,7 +73,7 @@ return(fdcont);		// return file descriptor
 
 int ry_addtext(char *line) {
 
-extern char ry_term[][];
+//extern char ry_term[][];	### bug fix
 
 int k, m, j;
 char *ptr;
@@ -99,8 +100,15 @@ if (k > 40)
 strcpy(bufferline, line);
 
 	for (j = 0; j < k; j++) {
-		if (bufferline[j] == 10 || bufferline[j] == 13|| bufferline[j]==7)
+		if (bufferline[j] == 10 || bufferline[j] == 13|| bufferline[j]==7) {
 			bufferline[j] = 32;
+			if (j < 40) {
+				strcat (bufferline, "                                      ");
+				bufferline[39] = '\0';
+				j = 0;
+				k = 0;
+			}
+		}
 	}
 
 
@@ -137,15 +145,19 @@ return(0);
 int show_rtty(void) {
 
 extern int use_rxvt;
-extern char ry_term[][];
+//extern char ry_term[][];		### bug fix
 extern int trxmode;
+//extern char hiscall[];
+extern int miniterm;
+extern int commentfield;
+extern char comment[];
 
-if (trxmode != DIGIMODE)
+if (trxmode != DIGIMODE || miniterm == 0)
 	return(-1);
 
 	attroff(A_STANDOUT);
-	if (use_rxvt == 0) attron(COLOR_PAIR(COLOR_YELLOW) | A_BOLD );
-	else  attron(COLOR_PAIR(COLOR_YELLOW) );
+	if (use_rxvt == 0) attron(COLOR_PAIR(COLOR_GREEN) | A_BOLD );
+	else  attron(COLOR_PAIR(COLOR_GREEN) );
 
 		mvprintw(1,0, "                                         ");
 		mvprintw(1,0, ry_term[0]);
@@ -157,6 +169,11 @@ if (trxmode != DIGIMODE)
 		mvprintw(4,0, ry_term[3]);
 		mvprintw(5,0, "                                         ");
 		mvprintw(5,0, ry_term[4]);
+		if (commentfield == 0) {
+			printcall();
+		} else {
+			mvprintw(12,54, comment);
+		}
 		refresh();
 		attron(A_STANDOUT);
 
@@ -169,7 +186,8 @@ int rx_rtty () {
 
 extern char hiscall[];
 extern int miniterm;
-extern char ry_term[][];
+
+//extern char ry_term[][];		### bug fix
 
 int i = 0;
 char line[40];
@@ -189,10 +207,12 @@ if (fdcont > 0)
 	}
 
 	i = read (fdcont, line, 39);
-
+//RX (2006-03-31 14:41Z): 		remove
 	if ( i > 0) {
 		line[i] = '\0';
-
+		
+		if (i > 23) 
+			strcpy(line, line + 24);
 
 		ry_addtext(line);
 
