@@ -28,7 +28,8 @@ void scroll_log(void)
 
 
 char inputbuffer[800];
-static int ii, kk, mm;
+static int ii, kk;
+int mm;
 
  FILE *fp;
 
@@ -93,7 +94,7 @@ if  ( (fp = fopen(logfile,"r"))  == NULL){
 
 	fclose(fp);
 
-
+	mm = qsonum - 1;
 
 	if (logline4[0] != ';') {
 		strncpy (qsonrstr, logline4 + 23, 4);
@@ -132,8 +133,10 @@ if  ( (fp = fopen(logfile,"r"))  == NULL){
 		}
 	} else qsonum = atoi(qsonrstr);
 
-		if (logline4[0] != ';') 
+		if (logline4[0] != ';' )
 			qsonum++;
+		else
+			qsonum = mm + 1;
 
 //		if((qsonum > highqsonr) && (lan_mutex == 2)) highqsonr++;
 		
