@@ -28,6 +28,16 @@
 
 static char searchresult[MAX_CALLS][82];
 static char result[MAX_CALLS][82];
+ /* DJ1YFK "worked window"-patch */
+ static char band_yfk[4]="";   
+ static char testcall_yfk[13]="";
+ static char hiscall_yfk[13]="            ";
+ int xx=0;
+ int bm[6];
+ int bandnr;
+ int yy=0;
+ /* */
+ 
 
  	int searchlog(char *searchstring)
 
@@ -150,7 +160,11 @@ char callmaster_location[80];
 		}
  		s_inputbuffer[0] = '\0';
  //
- 		for (r_index = 0; r_index < srch_index; r_index++){
+ 
+        // initialize array best matching callsigns
+        for(xx=0; xx<6; xx++) { bm[xx] = 0; }
+
+        for (r_index = 0; r_index < srch_index; r_index++){
 
 		 	strncpy (result[r_index], searchresult[r_index], 7);
 			result[r_index][6]='\0';
@@ -163,6 +177,67 @@ char callmaster_location[80];
 			strncat (result[r_index], searchresult[r_index]+28, 12);
 			strncat (result[r_index], searchresult[r_index]+52, 16);
 		}
+                       
+        /* DJ1YFK worked-window patch */
+        strncpy(band_yfk, searchresult[r_index],3);
+        band_yfk[4]= '\0';
+        bandnr = atoi(band_yfk);
+        
+        strncpy(testcall_yfk, searchresult[r_index]+29,12);
+        testcall_yfk[13]= '\0';
+        
+        // Create string with his call + whitespaces
+        strcpy(hiscall_yfk,"            ");
+        for (xx=0; xx < strlen(hiscall); xx++) {
+                hiscall_yfk[xx] = hiscall[xx];
+        }
+        // find out how many characters match
+        yy=0;
+        for (xx=0; xx < 13; xx++) {     
+                if(hiscall_yfk[xx] == testcall_yfk[xx]) {yy++;}
+        }
+
+        // delete QSOs that match worse than anything before
+        // of course still less-good magtching QSOs can be in the array,
+        // but *before* the better matching one, so they will be
+        // overwritten later.
+        switch (bandnr) {
+            case 160: { if (yy < bm[0]) {
+                    result[r_index][0] = '\0'; 
+                    }
+                    else { bm[0] = yy; }
+                    break;
+            }
+            case 80: { if (yy < bm[1]) {
+                    result[r_index][0] = '\0'; 
+                    }
+                    else { bm[1] = yy; }
+                    break;
+            }
+            case 40: { if (yy < bm[2]) {
+                    result[r_index][0] = '\0'; 
+                    }
+                    else { bm[2] = yy; }
+                    break;
+            }
+            case 20: { if (yy < bm[3]) {
+                    result[r_index][0] = '\0'; 
+                    }
+                    else { bm[3] = yy; }
+                    break;
+            }
+            case 15: { if (yy < bm[4]) {
+                    result[r_index][0] = '\0'; 
+                    }
+                    else { bm[4] = yy; }
+                    break;
+            }
+            case 10: { if (yy < bm[5]) {
+                    result[r_index][0] = '\0'; 
+                    }
+                    else { bm[5] = yy; }
+            }
+        } /* end of patch */
 
 
  	 	dupe = NODUPE;
@@ -821,12 +896,13 @@ else
   return(count);
 }
 // -------------------------------------------------------------------------------
-char multsfile[120] = "";		// global... (to be fixed)
+//char multsfile[80] = "";		// global... (to be fixed)
 // ----------------------------------------------load mults ------------------------
 int load_multipliers(void) {
 
 extern char mults_possible[MAX_MULTS][12];
 extern char multiplierlist[];
+extern char multsfile[];
 
  FILE *cfp ;
  char s_inputbuffer[186] =  "";
@@ -838,7 +914,7 @@ extern char multiplierlist[];
 			}
 
 			if (strlen(multiplierlist) != 0)
-				strncpy(multsfile , multiplierlist, strlen(multiplierlist)-1);
+				strncpy(multsfile , multiplierlist, strlen(multiplierlist) - 1);
 			else {
 				mvprintw(9,0,  "No multiplier file specified, exiting.. !!\n");
 				refresh();
