@@ -22,6 +22,7 @@
  	*
  	*              also updates windows every second
  	*--------------------------------------------------------------*/
+#include "globalvars.h"
 #include "time_update.h"
 
 int time_update(void)
@@ -29,24 +30,23 @@ int time_update(void)
 extern struct tm *time_ptr;
 extern int searchflg;
 extern char hiscall[];
-extern char logline0[];
-extern char logline1[];
-extern char logline2[];
-extern char logline3[];
-extern char logline4[];
 extern char qsonrstr[];
 extern int oldtens;
 extern int bandinx;
 extern int this_second;
 extern long system_secs;
+extern int miniterm;
 
 char time_buf[20];
 int tens  = 1;
 int j;
+int currentterm = 0;
 static int s;
 static int m;
 
-          	usleep(1000);
+
+
+		usleep(1000);
 
          	
           	get_time();
@@ -58,7 +58,10 @@ static int m;
 
 			if (tens != oldtens ){    /*  seconds */
 				oldtens  = tens;
-				
+
+				if (wpx == 1) {
+					if (minute_timer > 0) minute_timer-- ;
+				}
 
 				if (s >= 0) {
 					
@@ -70,11 +73,14 @@ static int m;
 					} else {
 						m++;
 					}
+					
+					currentterm = miniterm;
+					miniterm = 0;
 
 					clusterinfo(time_buf);  /* update cluster info (2 seconds)*/
 
                     attron(COLOR_PAIR(7) | A_STANDOUT);
-					
+
 					if ((strlen(hiscall) <= 1) || (searchflg == 0)) {
 						mvprintw(7,0, logline0);
 						mvprintw(8,0, logline1);
@@ -91,16 +97,18 @@ static int m;
 					showscore();			/* update  score  window every 2 seconds */
 					show_zones(bandinx);
 					s = 0;
-				
+					miniterm = currentterm;
 				}else s++;
 				
 				
-				
-				if (searchflg  == SEARCHWINDOW ){   /*    check routine erase  */
+			currentterm = miniterm;
+			miniterm = 0;
+
+			if (searchflg  == SEARCHWINDOW ){   /*    check routine erase  */
 					
 					attron(COLOR_PAIR(7) | A_STANDOUT);
-		
-		            if  (strlen(hiscall)  < 2){
+
+				if  (strlen(hiscall)  < 2){
 						for (j =  1;  j <= 8; j++){
 							if (j == 6) {
 								attron(A_STANDOUT);
@@ -111,11 +119,14 @@ static int m;
 						}
 							mvprintw(7,0, logline0);
 							mvprintw(8,0, logline1);
-					}
-							printcall();
 				}
-			
+							printcall();
 			}
-			return(0);
+			miniterm = currentterm;
+		}
+
+
+
+	return(0);
 }
 
