@@ -34,12 +34,14 @@ extern char controllerport[];
 extern int native_rig_fd;
 extern char speedstr[];
 extern int speed;
+extern char rttyoutput[];
 
 FILE *bfp = NULL;
 int i;
 char send_orion[3];
 char buff[8];
 int realspeed = 32;
+char outstring[120] = "";
 
 if (trxmode != CWMODE && trxmode != DIGIMODE)
 	return(1);
@@ -87,6 +89,17 @@ if (data_ready == 1 ) {
 		fclose(bfp);
        		}
 
+	}else if (keyerport == GMFSK){
+			sprintf (outstring, "echo %c%c%s%c%c",'"','\n',wkeyerbuffer,'\n','"'); 
+			strcat (outstring, " >> ");
+			if (strlen(rttyoutput) < 2) {
+				mvprintw (24, 0, "No modem file specified!");
+			}
+			strcat (outstring, rttyoutput);
+			system (outstring);
+		
+			wkeyerbuffer[0] = '\0';
+			data_ready = 0;			
 	}
 	else if (keyerport == ORION_KEYER && strlen(wkeyerbuffer) > 0) {
 		if  ( native_rig_fd == 0){
