@@ -44,7 +44,7 @@
 
 
 	char buf[181];
-	char buffer[82]= "";
+	char buffer[100]= "";
     	char standardexchange[70] = "";
 	
 	FILE *fp1,  *fp2;
@@ -113,7 +113,7 @@ mode
 			else if (buf[3] == 'S')
 				strcat(buffer, " PH 20");
 			else
-				strcat(buffer, "DIG 20");
+				strcat(buffer, " RY 20");
 
 /*------------------------------------------------------------------
 date
@@ -252,9 +252,11 @@ exchange given
 				}
 				else
 				{
+
 					strncat(buffer, standardexchange, 10);
 					strncat (buffer, "     ", strlen(buffer)-8);
 				}
+
 /*------------------------------------------------------------------
 his call
 -------------------------------------------------------------------*/
@@ -318,7 +320,7 @@ rprt given
 				}
 				else
 				{
-					if (strcmp(whichcontest, "ssa_mt") != 0)
+					if (strcmp(whichcontest, "ssa_mt") == 1)
 						strcat(buffer, " 0\n");
 					else
 						strcat(buffer, "\n");
@@ -330,7 +332,7 @@ rprt given
 		}
 
 
-	}
+	} // end while !eof
 
 	fclose(fp1);
 	fclose(fp2);
@@ -381,6 +383,7 @@ int  write_adif(void) {
   extern char exchange[];
   extern char whichcontest[];
   extern int exchange_serial;
+  extern char modem_mode[];
 
 //  char buf[81]="";	### bug fix
   char buf[181]="";
@@ -469,6 +472,8 @@ while  (fgets (buf,  sizeof(buf),  fp1))
             strcat(buffer, "<MODE:2>CW");
       else if (buf[3] == 'S')
             strcat(buffer, "<MODE:3>SSB");
+      else if (strcmp (modem_mode, "RTTY") == 0)
+      		strcat(buffer, "<MODE:4>RTTY");
       else
             strcat(buffer, "<MODE:4>DIGI");
 
